==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoresponder/translations/autoresponder_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstallungen</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Nur das erste mal</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Antworte auf Konferenzen</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Unsichtbar</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTO-ANTWORT:</translation>
    </message>
    <message>
        <source>I am busy.</source>
        <translation>Ich bin beschäftigt.</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/autoresponder/translations/autoresponder_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstallungen</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Nur das erste mal</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Antworte auf Konferenzen</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Unsichtbar</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose Status</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTO-ANTWORT:</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Ich bin beschäftigt.</translation>
    </message>
</context>
</TS>
